***********
Image Utils
***********

``import gouda.image``

Requirements
============

* `NumPy <https://github.com/numpy/numpy>`_
* `OpenCV <https://opencv.org/>`_

Methods
=======

.. automodule:: gouda.image
   :members:
